==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/phpsysinfo/includes/lang/en.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: en.php,v 1.1.1.2 2004/04/06 23:17:13 kazuyan Exp $

$text['title']          = 'System Information';

$text['vitals']         = 'System Vital';
$text['hostname']       = 'Canonical Hostname';
$text['ip']             = 'Listening IP';
$text['kversion']       = 'Kernel Version';
$text['uptime']         = 'Uptime';
$text['users']          = 'Current Users';
$text['loadavg']        = 'Load Averages';

$text['hardware']       = 'Hardware Information';
$text['numcpu']         = 'Processors';
$text['cpumodel']       = 'Model';
$text['mhz']            = 'Chip MHz';
$text['cache']          = 'Cache Size';
$text['bogomips']       = 'System Bogomips';
$text['pci']            = 'PCI Devices';
$text['ide']            = 'IDE Devices';
$text['scsi']           = 'SCSI Devices';

$text['netusage']       = 'Network Usage';
$text['device']         = 'Device';
$text['received']       = 'Received';
$text['sent']           = 'Sent';
$text['errors']         = 'Err/Drop';

$text['connections']	= 'Established Network Connections';

$text['memusage']       = 'Memory Usage';
$text['phymem']         = 'Physical Memory';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Mounted Filesystems';
$text['mount']          = 'Mount';
$text['partition']      = 'Partition';

$text['percent']        = 'Percent Capacity';
$text['type']           = 'Type';
$text['free']           = 'Free';
$text['used']           = 'Used';
$text['size']           = 'Size';
$text['totals']         = 'Totals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'none';

$text['capacity']       = 'Capacity'; 

$text['template']       = 'Template';
$text['language']       = 'Language';
$text['submit']         = 'Submit';
$text['created']        = 'Created by';

$text['days']           = 'days';
$text['hours']          = 'hours';
$text['minutes']        = 'minutes';
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/phpsysinfo/includes/lang/en.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: en.php,v 1.1.1.3 2007/09/13 20:19:58 kazuyan Exp $

$text['title']          = 'System Information';

$text['vitals']         = 'System Vital';
$text['hostname']       = 'Canonical Hostname';
$text['ip']             = 'Listening IP';
$text['kversion']       = 'Kernel Version';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Current Users';
$text['loadavg']        = 'Load Averages';

$text['hardware']       = 'Hardware Information';
$text['numcpu']         = 'Processors';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'CPU Speed';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache Size';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'PCI Devices';
$text['ide']            = 'IDE Devices';
$text['scsi']           = 'SCSI Devices';
$text['usb']            = 'USB Devices';

$text['netusage']       = 'Network Usage';
$text['device']         = 'Device';
$text['received']       = 'Received';
$text['sent']           = 'Sent';
$text['errors']         = 'Err/Drop';

$text['connections']    = 'Established Network Connections';

$text['memusage']       = 'Memory Usage';
$text['phymem']         = 'Physical Memory';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Mounted Filesystems';
$text['mount']          = 'Mount';
$text['partition']      = 'Partition';

$text['percent']        = 'Percent Capacity';
$text['type']           = 'Type';
$text['free']           = 'Free';
$text['used']           = 'Used';
$text['size']           = 'Size';
$text['totals']         = 'Totals';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'none';

$text['capacity']       = 'Capacity'; 

$text['template']       = 'Template';
$text['language']       = 'Language';
$text['submit']         = 'Submit';
$text['created']        = 'Created by';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'days';
$text['hours']          = 'hours';
$text['minutes']        = 'minutes';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&deg;C';
$text['degreeF']        = '&deg;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
